==> apache-superset-incubating-0.36.0-source.tar.gz: apache-superset-incubating-0.36.0rc3/superset-frontend/spec/javascripts/explore/components/RowCountLabel_spec.jsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from 'react';
import { shallow } from 'enzyme';
import { Label } from 'react-bootstrap';

import TooltipWrapper from './../../../../src/components/TooltipWrapper';

import RowCountLabel from '../../../../src/explore/components/RowCountLabel';

describe('RowCountLabel', () => {
  const defaultProps = {
    rowcount: 51,
    limit: 100,
  };

  it('is valid', () => {
    expect(React.isValidElement(<RowCountLabel {...defaultProps} />)).toBe(
      true,
    );
  });
  it('renders a Label and a TooltipWrapper', () => {
    const wrapper = shallow(<RowCountLabel {...defaultProps} />);
    expect(wrapper.find(Label)).toHaveLength(1);
    expect(wrapper.find(TooltipWrapper)).toHaveLength(1);
  });
  it('renders a danger when limit is reached', () => {
    const props = {
      rowcount: 100,
      limit: 100,
    };
    const wrapper = shallow(<RowCountLabel {...props} />);
    expect(
      wrapper
        .find(Label)
        .first()
        .props().bsStyle,
    ).toBe('danger');
  });
});

==> apache-superset-incubating-0.37.0-source.tar.gz: apache-superset-incubating-0.37.0rc4/superset-frontend/spec/javascripts/explore/components/RowCountLabel_spec.jsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from 'react';
import { shallow } from 'enzyme';
import { Label } from 'react-bootstrap';

import TooltipWrapper from 'src/components/TooltipWrapper';
import RowCountLabel from 'src/explore/components/RowCountLabel';

describe('RowCountLabel', () => {
  const defaultProps = {
    rowcount: 51,
    limit: 100,
  };

  it('is valid', () => {
    expect(React.isValidElement(<RowCountLabel {...defaultProps} />)).toBe(
      true,
    );
  });
  it('renders a Label and a TooltipWrapper', () => {
    const wrapper = shallow(<RowCountLabel {...defaultProps} />);
    expect(wrapper.find(Label)).toHaveLength(1);
    expect(wrapper.find(TooltipWrapper)).toHaveLength(1);
  });
  it('renders a danger when limit is reached', () => {
    const props = {
      rowcount: 100,
      limit: 100,
    };
    const wrapper = shallow(<RowCountLabel {...props} />);
    expect(wrapper.find(Label).first().props().bsStyle).toBe('danger');
  });
});
